package test.framework;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

public abstract class TestCase implements Test {
   private final String fName;

   public TestCase(String name) {
      this.fName = name;
   }

   // $FF: renamed from: assert (boolean) void
   protected void method_0(boolean condition) {
      if (!condition) {
         throw new AssertionFailedError();
      }
   }

   // $FF: renamed from: assert (java.lang.String, boolean) void
   protected void method_1(String message, boolean condition) {
      if (!condition) {
         throw new AssertionFailedError(message);
      }
   }

   protected void assertEquals(Object expected, Object actual) {
      if (!expected.equals(actual)) {
         this.method_1(this.notEqualsMessage("", expected, actual), false);
      }

   }

   protected void assertEquals(long expected, long actual) {
      if (expected != actual) {
         this.method_1(this.notEqualsMessage("", new Long(expected), new Long(actual)), false);
      }

   }

   protected void assertEquals(double expected, double actual, double delta) {
      if (Math.abs(expected - actual) > delta) {
         this.method_1(this.notEqualsMessage("", new Double(expected), new Double(actual)), false);
      }

   }

   protected void assertEquals(String message, Object expected, Object actual) {
      if (!expected.equals(actual)) {
         this.method_1(this.notEqualsMessage(message + " ", expected, actual), false);
      }

   }

   protected void assertEquals(String message, long expected, long actual) {
      if (expected != actual) {
         this.method_1(this.notEqualsMessage(message + " ", new Long(expected), new Long(actual)), false);
      }

   }

   protected void assertEquals(String message, double expected, double actual, double delta) {
      if (Math.abs(expected - actual) > delta) {
         this.method_1(this.notEqualsMessage(message + " ", new Double(expected), new Double(actual)), false);
      }

   }

   protected String notEqualsMessage(String message, Object expected, Object actual) {
      return message + "expected:\"" + expected + "\"but was:\"" + actual + "\"";
   }

   public void run(TestResult result) {
      result.startTest(this);
      this.setUp();

      try {
         this.runTest();
      } catch (AssertionFailedError e) {
         result.addFailure(this, e);
      } catch (Throwable e) {
         result.addError(this, e);
      }

      this.tearDown();
      result.endTest(this);
   }

   public int countTestCases() {
      return 1;
   }

   protected void runTest() throws Throwable {
      Method runMethod = null;

      try {
         runMethod = this.getClass().getMethod(this.fName);
      } catch (NoSuchMethodException e) {
         ((Throwable)e).fillInStackTrace();
         throw e;
      }

      try {
         runMethod.invoke(this);
      } catch (InvocationTargetException e) {
         ((Throwable)e).fillInStackTrace();
         throw e.getTargetException();
      } catch (IllegalAccessException e) {
         ((Throwable)e).fillInStackTrace();
         throw e;
      }
   }

   protected void setUp() {
   }

   protected void tearDown() {
   }

   public String name() {
      return this.fName;
   }

   public TestResult run() {
      TestResult result = this.defaultResult();
      this.run(result);
      return result;
   }

   protected TestResult defaultResult() {
      return new TestResult();
   }

   public String toString() {
      return this.getClass().getName() + "." + this.name();
   }
}
